Chiplotle Known Plotters — Chiplotle v0.2 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Chiplotle »
- Chiplotle v0.2 documentation »
- Chiplotle API »

# Chiplotle Known Plotters

class `chiplotle.plotters.` `DXY1300`(ser, **kwargs)
  Bases: `chiplotle.plotters.drawingplotter._DrawingPlotter`

class `chiplotle.plotters.` `DXY880`(ser, **kwargs)
  Bases: `chiplotle.plotters.drawingplotter._DrawingPlotter`

class `chiplotle.plotters.` `HP7475A`(ser, **kwargs)
  Bases: `chiplotle.plotters.drawingplotter._DrawingPlotter`

class `chiplotle.plotters.` `HP7550A`(ser, **kwargs)
  Bases: `chiplotle.plotters.drawingplotter._DrawingPlotter`

class `chiplotle.plotters.` `HP7595A`(ser, **kwargs)
  Bases: `chiplotle.plotters.drawingplotter._DrawingPlotter`

class `chiplotle.plotters.` `HP7596A`(ser, **kwargs)
  Bases: `chiplotle.plotters.drawingplotter._DrawingPlotter`

class `chiplotle.plotters.` `Plotter`(ser, **kwargs)

  Bases: `chiplotle.plotters.drawingplotter._DrawingPlotter`

  `abortCommand`()
    Tells the plotter to discard commands in its buffer.
  `absoluteCharSize`(w=None, h=None)
  `absoluteDirection`(run=1, rise=0)
  `accelSelect`(accel=None, pen=None)
  `actualPosition`
    Output the actual position of the plotter pen.
  `advanceFrame`()
  `advanceFullPage`()
  `advanceHalfPage`()
  `altCharSet`(n=0)
  `arcAbsolute`(x, y, aa, ca=5)
  `arcRelative`(x, y, aa, ca=5)
  `automaticPen`(p=None)
  `bufferLabel`(text=None)
  `bufferPlot`()
  `carouselType`
  `charChordAngle`(angle=5)
  `charPlot`(spaces=None, lines=None)
  `charSelectionMode`(switch=0, fallback=0)
  `charSet`(set=0)
  `charSlant`(tan=0)
  `chordTolerance`(type=0)
  `circle`(rad, ca=5)
  `clearDigitizer`()
  `commandedPosition`
  `defaultInstruction`()
  `defineLabelTerminator`(t='x03')
  `digitizePoint`()
  `digitizedPoint`
  `edgePolygon`()
  `edgeRectAbsolute`(x, y)
  `edgeRectRelative`(x, y)
  `enableCutLine`(n)
  `escapePlotterOn`()
  `fillPolygon`()
  `fillType`(type=1, space=None, angle=0)
  `forceSelect`(force=None, pen=None)
  `goto`(x, y)
    Alias for PA() with only one point
  `goto_bottom_left`()
  `goto_bottom_right`()
  `goto_center`()
  `goto_top_left`()
  `goto_top_right`()
  `id`
    Get id of plotter.
  `initializePlotter`()
  `inputWindow`(xLL=None, yLL=None, xUR=None, yUR=None)
  `label`(text)
  `labelLength`
  `lineType`(pattern, length=4)
  `margins`
    Read-only reference to MarginsInterface.
  `notReady`()
    what’s this for?
  `nudge`(x, y)
  `options`
  `outputError`
  `outputKey`
  `outputP1P2`
  `pageFeed`(n=None)
  `paperSize`(size=None)
  `penDown`(coords=None)
    Pen Down.
  `penThickness`(thickness=0.29999999999999999)
  `penUp`(coords=None)
    Pen Up.
  `plotAbsolute`(coords=None)

    Plot Absolute. Takes a tuple of any number of sets of points: (0,0,100,100,2500,1000) will go to three different points:

    > 0,0 100,100 2500,1000

  `plotPolygon`(n=0)
  `plotRelative`(coords=None)

    Plot Relative. Takes a tuple of any number of sets of points: (0,0,100,100,2500,1000) will go to three different points:

    > 0,0 100,100 2500,1000

  `printBufferedLabel`()
  `relCharSize`(w=None, h=None)
  `replot`(n=1)
  `rotate`(angle=0)
  `scale`(xMin, xMax, yMin, yMax)
  `selectAltCharSet`()
  `selectPen`(penNum=0)
  `selectStandardCharSet`()
  `shadeRectAbsolute`(x, y)
  `shadeRectRelative`(x, y)
  `status`
  `symbolMode`(char=None)
  `tickLength`(tp=0.5, tn=0.5)
  `velocitySelect`(v=None, pen=None)
    Set pen’s velocity.
  `write`(data)
    Public access for writing to serial port. data can be an iterator, a string or an _HPGLCommand.
  `writeFile`(filename)
    Sends the HPGL content of the given filename to the plotter.
  `writeToDisplay`(text)
  `xTick`()
  `yTick`()

### Navigation

- index
- modules |
- next |
- previous |
- Chiplotle »
- Chiplotle v0.2 documentation »
- Chiplotle API »